// -*- C++ -*-
/*!
 * @file  Pi_RTIMU.h
 * @brief IMU Component using RTIMULib
 * @date  $Date$
 *
 * $Id$
 */

#ifndef PI_RTIMU_H
#define PI_RTIMU_H

#include <rtm/idl/BasicDataTypeSkel.h>
#include <rtm/idl/ExtendedDataTypesSkel.h>
#include <rtm/idl/InterfaceDataTypesSkel.h>

// Service implementation headers
// <rtc-template block="service_impl_h">

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="consumer_stub_h">

// </rtc-template>

// Service Consumer stub headers
// <rtc-template block="port_stub_h">
// </rtc-template>

#include <rtm/Manager.h>
#include <rtm/DataFlowComponentBase.h>
#include <rtm/CorbaPort.h>
#include <rtm/DataInPort.h>
#include <rtm/DataOutPort.h>

using namespace RTC;

/*!
 * @class Pi_RTIMU
 * @brief IMU Component using RTIMULib
 *
 * RTIMULibを使用したIMUセンサモジュールRTC
 *
 */
class Pi_RTIMU
  : public RTC::DataFlowComponentBase
{
 public:
  /*!
   * @brief constructor
   * @param manager Maneger Object
   */
  Pi_RTIMU(RTC::Manager* manager);

  /*!
   * @brief destructor
   */
  ~Pi_RTIMU();

  // <rtc-template block="public_attribute">
  
  // </rtc-template>

  // <rtc-template block="public_operation">
  
  // </rtc-template>

  /***
   *
   * The initialize action (on CREATED->ALIVE transition)
   * formaer rtc_init_entry() 
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
   virtual RTC::ReturnCode_t onInitialize();

  /***
   *
   * The finalize action (on ALIVE->END transition)
   * formaer rtc_exiting_entry()
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onFinalize();

  /***
   *
   * The startup action when ExecutionContext startup
   * former rtc_starting_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onStartup(RTC::UniqueId ec_id);

  /***
   *
   * The shutdown action when ExecutionContext stop
   * former rtc_stopping_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onShutdown(RTC::UniqueId ec_id);

  /***
   *
   * The activated action (Active state entry action)
   * former rtc_active_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
   virtual RTC::ReturnCode_t onActivated(RTC::UniqueId ec_id);

  /***
   *
   * The deactivated action (Active state exit action)
   * former rtc_active_exit()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
   virtual RTC::ReturnCode_t onDeactivated(RTC::UniqueId ec_id);

  /***
   *
   * The execution action that is invoked periodically
   * former rtc_active_do()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
   virtual RTC::ReturnCode_t onExecute(RTC::UniqueId ec_id);

  /***
   *
   * The aborting action when main logic error occurred.
   * former rtc_aborting_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onAborting(RTC::UniqueId ec_id);

  /***
   *
   * The error action in ERROR state
   * former rtc_error_do()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onError(RTC::UniqueId ec_id);

  /***
   *
   * The reset action that is invoked resetting
   * This is same but different the former rtc_init_entry()
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onReset(RTC::UniqueId ec_id);
  
  /***
   *
   * The state update action that is invoked after onExecute() action
   * no corresponding operation exists in OpenRTm-aist-0.2.0
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onStateUpdate(RTC::UniqueId ec_id);

  /***
   *
   * The action that is invoked when execution context's rate is changed
   * no corresponding operation exists in OpenRTm-aist-0.2.0
   *
   * @param ec_id target ExecutionContext Id
   *
   * @return RTC::ReturnCode_t
   * 
   * 
   */
  // virtual RTC::ReturnCode_t onRateChanged(RTC::UniqueId ec_id);


 protected:
  // <rtc-template block="protected_attribute">
  
  // </rtc-template>

  // <rtc-template block="protected_operation">
  
  // </rtc-template>

  // Configuration variable declaration
  // <rtc-template block="config_declare">
  /*!
   * RTIMULibの設定ファイル名（拡張子を除いたファイル名）を指定する
   * 。
   * "RTIMULib"と記述した場合"RTIMULib.ini"が読み込まれる。
   * - Name: string Inifile
   * - DefaultValue: ./RTIMULib
   */
  std::string m_Inifile;

  // </rtc-template>

  // DataInPort declaration
  // <rtc-template block="inport_declare">
  
  // </rtc-template>


  // DataOutPort declaration
  // <rtc-template block="outport_declare">
  RTC::TimedAcceleration3D m_accel;
  /*!
   * 加速度センサの計測値
   * - Type: RTC::TimedAcceleration3D
   * - Unit: G
   */
  OutPort<RTC::TimedAcceleration3D> m_accelOut;
  RTC::TimedVector3D m_compass;
  /*!
   * 地磁気センサの計測値
   * - Type: RTC::TimedVector3D
   * - Unit: uT
   */
  OutPort<RTC::TimedVector3D> m_compassOut;
  RTC::TimedAngularAcceleration3D m_gyro;
  /*!
   * ジャイロセンサの計測値
   * - Type: RTC::TimedAngularVelocity3D
   * - Unit: rad/s
   */
  OutPort<RTC::TimedAngularAcceleration3D> m_gyroOut;
  RTC::TimedDouble m_temperature;
  /*!
   * 温度センサの計測値
   * - Type: RTC::TimedDouble
   * - Unit: 度
   */
  OutPort<RTC::TimedDouble> m_temperatureOut;
  RTC::TimedOrientation3D m_pose;
  /*!
   * センサ情報から計算した姿勢(オイラー角)
   * - Type: RTC::TimedOrientation3D
   * - Unit: rad
   */
  OutPort<RTC::TimedOrientation3D> m_poseOut;
  RTC::TimedDouble m_pressure;
  /*!
   * 気圧センサの計測値
   * - Type: RTC::TimedDouble
   */
  OutPort<RTC::TimedDouble> m_pressureOut;
  RTC::TimedDouble m_humidity;
  /*!
   * 湿度センサの計測値
   * - Type: RTC::TimedDouble
   */
  OutPort<RTC::TimedDouble> m_humidityOut;
  RTC::TimedQuaternion m_qpose;
  /*!
   * センサ情報から計算した姿勢(クォータニオン)
   * - Type: RTC::TimedQuaternion
   */
  OutPort<RTC::TimedQuaternion> m_qposeOut;
  
  // </rtc-template>

  // CORBA Port declaration
  // <rtc-template block="corbaport_declare">
  
  // </rtc-template>

  // Service declaration
  // <rtc-template block="service_declare">
  
  // </rtc-template>

  // Consumer declaration
  // <rtc-template block="consumer_declare">
  
  // </rtc-template>

 private:
  // <rtc-template block="private_attribute">
  
  // </rtc-template>

  // <rtc-template block="private_operation">
  
  // </rtc-template>

};


extern "C"
{
  DLL_EXPORT void Pi_RTIMUInit(RTC::Manager* manager);
};

#endif // PI_RTIMU_H
