// -*- C++ -*-
/*!
 * @file  Pi_RTIMU_View.cpp
 * @brief Pi_RTIMU Viewer
 * @date $Date$
 *
 * $Id$
 */

#include "Pi_RTIMU_View.h"

// Module specification
// <rtc-template block="module_spec">
static const char* pi_rtimu_view_spec[] =
  {
    "implementation_id", "Pi_RTIMU_View",
    "type_name",         "Pi_RTIMU_View",
    "description",       "Pi_RTIMU Viewer",
    "version",           "1.0.0",
    "vendor",            "MEDIA DRIVE",
    "category",          "Sensor",
    "activity_type",     "PERIODIC",
    "kind",              "DataFlowComponent",
    "max_instance",      "1",
    "language",          "C++",
    "lang_type",         "compile",
    ""
  };
// </rtc-template>

/*!
 * @brief constructor
 * @param manager Maneger Object
 */
Pi_RTIMU_View::Pi_RTIMU_View(RTC::Manager* manager)
    // <rtc-template block="initializer">
  : RTC::DataFlowComponentBase(manager),
    m_accelIn("accel", m_accel),
    m_compassIn("compass", m_compass),
    m_gyroIn("gyro", m_gyro),
    m_poseIn("pose", m_pose),
    m_qposeIn("qpose", m_qpose),
    m_temperatureIn("temperature", m_temperature),
    m_pressureIn("pressure", m_pressure),
    m_humidityIn("humidity", m_humidity)

    // </rtc-template>
{
}

/*!
 * @brief destructor
 */
Pi_RTIMU_View::~Pi_RTIMU_View()
{
}



RTC::ReturnCode_t Pi_RTIMU_View::onInitialize()
{
  // Registration: InPort/OutPort/Service
  // <rtc-template block="registration">
  // Set InPort buffers
  addInPort("accel", m_accelIn);
  addInPort("compass", m_compassIn);
  addInPort("gyro", m_gyroIn);
  addInPort("pose", m_poseIn);
  addInPort("qpose", m_qposeIn);
  addInPort("temperature", m_temperatureIn);
  addInPort("pressure", m_pressureIn);
  addInPort("humidity", m_humidityIn);
  
  // Set OutPort buffer
  
  // Set service provider to Ports
  
  // Set service consumers to Ports
  
  // Set CORBA Service Ports
  
  // </rtc-template>

  // <rtc-template block="bind_config">
  // </rtc-template>
  
  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t Pi_RTIMU_View::onFinalize()
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Pi_RTIMU_View::onStartup(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Pi_RTIMU_View::onShutdown(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/


RTC::ReturnCode_t Pi_RTIMU_View::onActivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t Pi_RTIMU_View::onDeactivated(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}


RTC::ReturnCode_t Pi_RTIMU_View::onExecute(RTC::UniqueId ec_id)
{
  if(m_accelIn.isNew())
  {
    m_accelIn.read();
    std::cout << "Accel: "
     << "ax:" << m_accel.data.ax
     << "ay:" << m_accel.data.ay
     << "az:" << m_accel.data.az << std::endl;
  }

  if(m_compassIn.isNew())
  {
    m_compassIn.read();
    std::cout << "compass: "
    << "x:" << m_compass.data.x
    << "y:" << m_compass.data.y
    << "z:" << m_compass.data.z << std::endl;
  }

  if(m_gyroIn.isNew())
  {
    m_gyroIn.read();
    std::cout << "gyro: "
    << "aax:" << m_gyro.data.aax
    << "aay:" << m_gyro.data.aay
    << "aaz:" << m_gyro.data.aaz << std::endl;
  }

  if(m_poseIn.isNew())
  {
    m_poseIn.read();
    std::cout << "pose: "
    << "r:" << m_pose.data.r
    << "p:" << m_pose.data.p
    << "y:" << m_pose.data.y << std::endl;
  }

  if(m_qposeIn.isNew())
  {
    m_qposeIn.read();
    std::cout << "q = [ "
    << m_qpose.data.x
    << ", " << m_qpose.data.y
    << ", " << m_qpose.data.z
    << ", " << m_qpose.data.w << " ]" << std::endl;
  }

  if(m_temperatureIn.isNew())
  {
    m_temperatureIn.read();
    std::cout << "Temperature: " << m_temperature.data << std::endl;
  }

  if(m_pressureIn.isNew())
  {
    m_pressureIn.read();
    std::cout << "Pressure: " << m_pressure.data << std::endl;
  }

  if(m_humidityIn.isNew())
  {
    m_humidityIn.read();
    std::cout << "Humidity: " << m_humidity.data << std::endl;
  }

  return RTC::RTC_OK;
}

/*
RTC::ReturnCode_t Pi_RTIMU_View::onAborting(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Pi_RTIMU_View::onError(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Pi_RTIMU_View::onReset(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Pi_RTIMU_View::onStateUpdate(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/

/*
RTC::ReturnCode_t Pi_RTIMU_View::onRateChanged(RTC::UniqueId ec_id)
{
  return RTC::RTC_OK;
}
*/



extern "C"
{
 
  void Pi_RTIMU_ViewInit(RTC::Manager* manager)
  {
    coil::Properties profile(pi_rtimu_view_spec);
    manager->registerFactory(profile,
                             RTC::Create<Pi_RTIMU_View>,
                             RTC::Delete<Pi_RTIMU_View>);
  }
  
};


